@@ -53,14 +53,6 @@
 #define PREF_SEA_THRESHOLD			100
 
 
-#define ID_FILE_OPEN              10010
-#define ID_FILE_QUIT              10020
-
-#define ID_SETTINGS_TOOLBAR       11010
-#define ID_SETTINGS_STATUSBAR     11020
-#define ID_SETTINGS_SAVEOPTIONS   11030
-#define ID_SETTINGS_CONFIGURE     11040
-
 #define ID_HELP_CONTENTS           1002
 #define ID_HELP_ABOUT              1003
 
